@@ -538,7 +538,7 @@ class AsyncNeo4jPool(AsyncIOPool):
             # checks if the code is an error that is caused by the client. In
             # this case there is no sense in trying to fetch a RT from another
             # router. Hence, the driver should fail fast during discovery.
-            if e.is_fatal_during_discovery():
+            if e._is_fatal_during_discovery():
                 raise
         except (ServiceUnavailable, SessionExpired):
             pass
@@ -679,7 +679,7 @@ class AsyncNeo4jPool(AsyncIOPool):
         routing_table = await self.get_or_create_routing_table(database)
         servers = routing_table.servers()
         for address in list(self.connections):
-            if address.unresolved not in servers:
+            if address._unresolved not in servers:
                 await super(AsyncNeo4jPool, self).deactivate(address)
 
     async def ensure_routing_table_is_fresh(
